@@ -129,7 +129,7 @@ class WP_Themes_List_Table extends WP_List_Table {
 		// Fallthrough.
 		printf(
 			/* translators: %s: Network title. */
-			__( 'Only the current theme is available to you. Contact the %s administrator for information about accessing additional themes.' ),
+			__( 'Only the active theme is available to you. Contact the %s administrator for information about accessing additional themes.' ),
 			get_site_option( 'site_name' )
 		);
 	}
@@ -212,7 +212,7 @@ class WP_Themes_List_Table extends WP_List_Table {
 				'<a href="%s" class="activatelink" title="%s">%s</a>',
 				$activate_link,
 				/* translators: %s: Theme name. */
-				esc_attr( sprintf( __( 'Activate &#8220;%s&#8221;' ), $title ) ),
+				esc_attr( sprintf( _x( 'Activate &#8220;%s&#8221;', 'theme' ), $title ) ),
 				__( 'Activate' )
 			);
 
@@ -247,12 +247,12 @@ class WP_Themes_List_Table extends WP_List_Table {
 
 			<span class="screenshot hide-if-customize">
 				<?php if ( $screenshot ) : ?>
-					<img src="<?php echo esc_url( $screenshot ); ?>" alt="" />
+					<img src="<?php echo esc_url( $screenshot . '?ver=' . $theme->version ); ?>" alt="" />
 				<?php endif; ?>
 			</span>
 			<a href="<?php echo wp_customize_url( $stylesheet ); ?>" class="screenshot load-customize hide-if-no-customize">
 				<?php if ( $screenshot ) : ?>
-					<img src="<?php echo esc_url( $screenshot ); ?>" alt="" />
+					<img src="<?php echo esc_url( $screenshot . '?ver=' . $theme->version ); ?>" alt="" />
 				<?php endif; ?>
 			</a>
 
@@ -302,14 +302,14 @@ class WP_Themes_List_Table extends WP_List_Table {
 	public function search_theme( $theme ) {
 		// Search the features.
 		foreach ( $this->features as $word ) {
-			if ( ! in_array( $word, $theme->get( 'Tags' ) ) ) {
+			if ( ! in_array( $word, $theme->get( 'Tags' ), true ) ) {
 				return false;
 			}
 		}
 
 		// Match all phrases.
 		foreach ( $this->search_terms as $word ) {
-			if ( in_array( $word, $theme->get( 'Tags' ) ) ) {
+			if ( in_array( $word, $theme->get( 'Tags' ), true ) ) {
 				continue;
 			}
 
