@@ -8,12 +8,14 @@
  *
  * @package WordPress
  * @subpackage Twenty_Twenty
- * @since 1.0.0
+ * @since Twenty Twenty 1.0
  */
 
 if ( ! class_exists( 'TwentyTwenty_Script_Loader' ) ) {
 	/**
 	 * A class that provides a way to add `async` or `defer` attributes to scripts.
+	 *
+	 * @since Twenty Twenty 1.0
 	 */
 	class TwentyTwenty_Script_Loader {
 
@@ -22,6 +24,8 @@ if ( ! class_exists( 'TwentyTwenty_Script_Loader' ) ) {
 		 *
 		 * If #12009 lands in WordPress, this function can no-op since it would be handled in core.
 		 *
+		 * @since Twenty Twenty 1.0
+		 *
 		 * @link https://core.trac.wordpress.org/ticket/12009
 		 *
 		 * @param string $tag    The script tag.
@@ -29,7 +33,7 @@ if ( ! class_exists( 'TwentyTwenty_Script_Loader' ) ) {
 		 * @return string Script HTML string.
 		 */
 		public function filter_script_loader_tag( $tag, $handle ) {
-			foreach ( [ 'async', 'defer' ] as $attr ) {
+			foreach ( array( 'async', 'defer' ) as $attr ) {
 				if ( ! wp_scripts()->get_data( $handle, $attr ) ) {
 					continue;
 				}
